@@ -1,4 +1,4 @@
 """ladybug-charts library"""
 
 # load all the functions that extends ladybug core library
-import ladybug_charts._extend_data
+import ladybug_charts._extend_ladybug
