@@ -25,7 +25,7 @@ from .utils import Strategy, StrategyParameters
 from ladybug.datacollection import HourlyContinuousCollection, \
     HourlyDiscontinuousCollection, MonthlyCollection, DailyCollection, BaseCollection
 from ladybug.windrose import WindRose
-from ladybug.color import Color, Colorset
+from ladybug.color import Color, Colorset, ColorRange
 from ladybug_pandas.series import Series
 from ladybug import psychrometrics as psy
 from ladybug.sunpath import Sunpath
@@ -41,7 +41,8 @@ pio.templates.default = 'plotly_white'
 
 def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousCollection],
              min_range: float = None, max_range: float = None,
-             colors: List[Color] = None, title: str = None, show_title: bool = False) -> Figure:
+             colors: List[Color] = None, title: str = None, show_title: bool = False,
+             num_labels: int = None, labels: List[float] = None) -> Figure:
     """Create a plotly heat map figure from Ladybug Hourly data.
 
     Args:
@@ -55,6 +56,8 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
         title: A string to be used as the title of the plot. If not set, the name
             of the data will be used. Defaults to None.
         show_title: A boolean to show or hide the title of the chart. Defaults to False.
+        num_labels: The number of labels to be used in the legend. Defaults to None.
+        labels: A list of floats to be used as labels for the legend. Defaults to None. 
 
     Returns:
         A plotly figure.
@@ -65,7 +68,9 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
         f' Instead got {type(hourly_data)}'
 
     if isinstance(hourly_data, HourlyDiscontinuousCollection):
-        hourly_data = discontinuous_to_continuous(hourly_data)
+        hourly_data, data_range = discontinuous_to_continuous(hourly_data)
+    else:
+        data_range = [hourly_data.min, hourly_data.max]
 
     var = hourly_data.header.data_type.name
     df = dataframe()
@@ -76,16 +81,18 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
     if min_range != None and max_range != None:
         range_z = [min_range, max_range]
     elif min_range != None and max_range == None:
-        range_z = [min_range, 5 * ceil(df[var].max() / 5)]
+        range_z = [min_range, data_range[1]]
     elif min_range == None and max_range != None:
-        range_z = [5 * floor(df[var].min() / 5), max_range]
+        range_z = [data_range[0], max_range]
     else:
-        # Set maximum and minimum according to data
-        range_z = [5 * floor(df[var].min() / 5), 5 * ceil(df[var].max() / 5)]
+        range_z = [data_range[0], data_range[1]]
 
     if not colors:
         colors = color_set[ColorSet.original.value]
 
+    nticks = num_labels
+    dtick = labels
+
     fig = go.Figure(
         data=go.Heatmap(
             y=df["hour"],
@@ -103,7 +110,7 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
                 + "</b><br>Month: %{customdata[0]}<br>Day: %{customdata[1]}<br>Hour: %{y}:00<br>"
             ),
             name="",
-            colorbar=dict(title=var_unit),
+            colorbar=dict(title=var_unit, nticks=nticks, dtick=dtick, thickness=10),
         )
     )
 
@@ -117,7 +124,7 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
             'y': 1,
             'x': 0.5,
             'xanchor': 'center',
-            'yanchor': 'top'
+            'yanchor': 'top',
         }
     else:
         if title:
@@ -131,6 +138,7 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
             l=20, r=20, t=33, b=20),
         yaxis_nticks=13,
         title=fig_title,
+        title_pad=dict(t=5)
     )
     fig.update_xaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
     fig.update_yaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
@@ -159,8 +167,6 @@ def _monthly_bar(data: MonthlyCollection, var: str, var_unit: str,
     return go.Bar(
         x=df['month_names'],
         y=[round(val, 2) for val in data.values],
-        text=[f'{round(val, 2)} {var_unit}' for val in data.values],
-        textposition='auto',
         customdata=np.stack((df["month_names"],), axis=-1),
         hovertemplate=(
             '<br>%{y} '
@@ -168,7 +174,7 @@ def _monthly_bar(data: MonthlyCollection, var: str, var_unit: str,
             + ' in %{customdata[0]}'
             + '<extra></extra>'),
         marker_color=rgb_to_hex(color),
-        name=var
+        name=var + ' ' + var_unit
     )
 
 
@@ -201,7 +207,7 @@ def _daily_bar(data: DailyCollection, var: str, var_unit: str,
             + ' %{customdata[1]} <br>'
             + '<extra></extra>'),
         marker_color=rgb_to_hex(color),
-        name=var
+        name=var + ' ' + var_unit
     )
 
 
@@ -289,7 +295,7 @@ def bar_chart(data: Union[List[MonthlyCollection], List[DailyCollection]],
         title=fig_title,
         legend={
             'x': 0,
-            'y': 1.1,
+            'y': 1.2,
         }
     )
     fig.update_xaxes(dtick="M1", tickformat="%b", ticklabelmode="period",
@@ -301,7 +307,8 @@ def bar_chart(data: Union[List[MonthlyCollection], List[DailyCollection]],
 
 
 def _bar_chart_single_data(data: Union[MonthlyCollection, DailyCollection],
-                           chart_type: str = 'monthly', chart_title: str = None,
+                           chart_type: str = 'monthly', title: str = None,
+                           show_title: bool = False,
                            color: Color = None) -> Figure:
     """Create a plotly bar chart figure from a ladybug monthly or daily data object.
 
@@ -309,8 +316,10 @@ def _bar_chart_single_data(data: Union[MonthlyCollection, DailyCollection],
         data: A ladybug monthly or daily data object.
         chart_type: A string to determine the type of chart to be created.
             Accepted values are 'monthly' and 'daily'. Defaults to 'monthly'.
-        chart_title: A string to be used as the title of the plot. If not set, the
+        title: A string to be used as the title of the plot. If not set, the
             names of data will be used to create a title for the chart. Defaults to None.
+        show_title: A boolean to set whether to show the title of the chart.
+            Defaults to False.
         color: A ladybug color object. If not set, random colors will be used.
 
     Returns:
@@ -326,21 +335,32 @@ def _bar_chart_single_data(data: Union[MonthlyCollection, DailyCollection],
         var_unit = data.header.unit
         bar = _daily_bar(data, var, var_unit, color)
 
-    chart_title = chart_title if chart_title else var
+    chart_title = title if title else var
 
     fig = go.Figure(bar)
     fig.update_xaxes(dtick="M1", tickformat="%b", ticklabelmode="period")
     fig.update_yaxes(title_text='('+var_unit+')')
-    fig.update_layout(
-        template='plotly_white',
-        margin=dict(l=20, r=20, t=33, b=20),
-        yaxis_nticks=13,
-        title={
+
+    # setting the title for the figure
+    if show_title:
+        fig_title = {
             'text': chart_title,
             'y': 1,
             'x': 0.5,
             'xanchor': 'center',
-            'yanchor': 'top'}
+            'yanchor': 'top'
+        }
+    else:
+        if title:
+            raise ValueError(
+                f'Title is set to "{title}" but show_title is set to False.')
+        fig_title = None
+
+    fig.update_layout(
+        template='plotly_white',
+        margin=dict(l=20, r=20, t=33, b=20),
+        yaxis_nticks=13,
+        title=fig_title,
     )
     fig.update_xaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
     fig.update_yaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
@@ -349,14 +369,17 @@ def _bar_chart_single_data(data: Union[MonthlyCollection, DailyCollection],
 
 
 def monthly_bar_chart(data: MonthlyCollection,
-                      chart_title: str = None,
+                      title: str = None,
+                      show_title: bool = False,
                       color: Color = None) -> Figure:
     """Create a plotly  bar chart figure from a ladybug monthly data object.
 
     Args:
         data: A ladybug MonthlyCollection object.
-        chart_title: A string to be used as the title of the plot. If not set, the name
+        title: A string to be used as the title of the plot. If not set, the name
             of the data will be used. Defaults to None.
+        show_title: A boolean to set whether to show the title of the chart.
+            Defaults to False.
         color: A Ladybug color object. If not set, a random color will be used. Defaults
             to None.
 
@@ -366,18 +389,21 @@ def monthly_bar_chart(data: MonthlyCollection,
     assert isinstance(data, MonthlyCollection), 'Only ladybug monthly data is'\
         f' supported. Instead got {type(data)}'
 
-    return _bar_chart_single_data(data, 'monthly', chart_title=chart_title, color=color)
+    return _bar_chart_single_data(data, 'monthly', title, show_title, color=color)
 
 
 def daily_bar_chart(data: DailyCollection,
-                    chart_title: str = None,
+                    title: str = None,
+                    show_title: bool = False,
                     color: Color = None) -> Figure:
     """Create a plotly bar chart figure from a ladybug daily data object.
 
     Args:
         data: A ladybug DailyCollection object.
-        chart_title: A string to be used as the title of the plot. If not set, the name
+        title: A string to be used as the title of the plot. If not set, the name
             of the data will be used. Defaults to None.
+        show_title: A boolean to determine whether to show the title of the plot.
+            Defaults to False.
         color: A Ladybug color object. If not set, a random color will be used. Defaults
             to None.
 
@@ -387,7 +413,7 @@ def daily_bar_chart(data: DailyCollection,
     assert isinstance(data, DailyCollection), 'Only ladybug daily data is'\
         f' supported. Instead got {type(data)}'
 
-    return _bar_chart_single_data(data, 'daily', chart_title=chart_title, color=color)
+    return _bar_chart_single_data(data, 'daily', title, show_title, color)
 
 
 def hourly_line_chart(data: HourlyContinuousCollection, color: Color = None) -> Figure:
@@ -497,12 +523,16 @@ def hourly_line_chart(data: HourlyContinuousCollection, color: Color = None) ->
     return fig
 
 
-def per_hour_line_chart(data: HourlyContinuousCollection,
+def per_hour_line_chart(data: HourlyContinuousCollection, title: str = None,
+                        show_title: bool = False,
                         color: Color = None) -> Figure:
     """Create a plotly per hour line chart figure from a ladybug hourly continuous data.
 
     Args:
         data: A ladybug HourlyContinuousCollection object.
+        title: A string to be used as the title of the plot. Defaults to None.
+        show_title: A boolean to determine whether to show the title of the plot.
+            Defaults to False.
         color: A Ladybug color object. If not set, a random color will be used. Defaults
             to None.
 
@@ -582,16 +612,29 @@ def per_hour_line_chart(data: HourlyContinuousCollection,
     fig.update_xaxes(
         ticktext=["6", "12", "18"], tickvals=["6", "12", "18"], tickangle=0
     )
+
+    chart_title = title if title else var + f' ({var_unit})'
+
+    # setting the title for the figure
+    if show_title:
+        fig_title = {
+            'text': chart_title,
+            'y': 1,
+            'x': 0.5,
+            'xanchor': 'center',
+            'yanchor': 'top'
+        }
+    else:
+        if title:
+            raise ValueError(
+                f'Title is set to "{title}" but show_title is set to False.')
+        fig_title = None
+
     fig.update_layout(
         template='plotly_white',
         dragmode=False,
         margin=dict(l=20, r=20, t=55, b=20),
-        title={
-            'text': var + f' ({var_unit})',
-            'y': 1,
-            'x': 0.5,
-            'xanchor': 'center',
-            'yanchor': 'top'}
+        title=fig_title
     )
 
     return fig
@@ -629,8 +672,8 @@ def wind_rose(wind_rose: WindRose, title: str = None, show_title: bool = False)
     wind_dir = wind_rose.direction_data_collection
 
     if isinstance(wind_speed, HourlyDiscontinuousCollection):
-        wind_speed = discontinuous_to_continuous(wind_speed)
-        wind_dir = discontinuous_to_continuous(wind_dir)
+        wind_speed = discontinuous_to_continuous(wind_speed)[0]
+        wind_dir = discontinuous_to_continuous(wind_dir)[0]
 
     df = dataframe()
     series = Series(wind_speed)
@@ -652,8 +695,16 @@ def wind_rose(wind_rose: WindRose, title: str = None, show_title: bool = False)
     else:
         df = df.loc[(df["hour"] <= end_hour) | (df["hour"] >= start_hour)]
 
-    spd_colors = [rgb_to_hex(color) for color in wind_rose.legend_parameters.colors]
     spd_bins = [-1, 0.5, 1.5, 3.3, 5.5, 7.9, 10.7, 13.8, 17.1, 20.7, np.inf]
+    # Create a color range if the colorset does not have 11 colors
+    if len(wind_rose.legend_parameters.colors) < 11:
+        domain = [spd_bins[0], spd_bins[-2]+1]
+        color_range = ColorRange(
+            colors=wind_rose.legend_parameters.colors, domain=domain)
+        spd_colors = [rgb_to_hex(color_range.color(item)) for item in spd_bins]
+    else:
+        spd_colors = [rgb_to_hex(color) for color in wind_rose.legend_parameters.colors]
+
     spd_labels = _speed_labels(spd_bins, units="m/s")
     dir_bins = np.arange(-22.5 / 2, 370, 22.5)
     dir_labels = (dir_bins[:-1] + dir_bins[1:]) / 2
@@ -744,7 +795,7 @@ def wind_rose(wind_rose: WindRose, title: str = None, show_title: bool = False)
 
 
 def psych_chart(psych: PsychrometricChart, data: BaseCollection = None,
-                title: str = None, polygon_pmv: PolygonPMV = None,
+                title: str = None, show_title: bool = False, polygon_pmv: PolygonPMV = None,
                 strategies: List[Strategy] = [Strategy.comfort],
                 strategy_parameters: StrategyParameters = StrategyParameters(),
                 solar_data: HourlyContinuousCollection = None,
@@ -755,6 +806,7 @@ def psych_chart(psych: PsychrometricChart, data: BaseCollection = None,
         psych: A ladybug PsychrometricChart object.
         data: A ladybug DataCollection object.
         title: A title for the plot. Defaults to None.
+        show_title: A boolean to show or hide the title. Defaults to False.
         polygon_pmv: A ladybug PolygonPMV object. If provided, polygons will be drawn.
             Defaults to None.
         strategies: A list of strategies to be applied to the chart. Accepts a list of
@@ -773,7 +825,7 @@ def psych_chart(psych: PsychrometricChart, data: BaseCollection = None,
     Returns:
         A plotly figure.
     """
-    return _psych_chart(psych, data, title, polygon_pmv, strategies,
+    return _psych_chart(psych, data, title, show_title, polygon_pmv, strategies,
                         strategy_parameters, solar_data, colors)
 
 
@@ -847,10 +899,10 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
     times = times - delta
 
     if not data:
-        var_color = "orange"
+        var_color = rgb_to_hex(colorset[-1])
         marker_size = 3
     else:
-        var_color = 'silver'
+        var_color = '#8c8e91'
         vals = solpos[var_name]
         marker_size = (((vals - vals.min()) / vals.max()) + 1) * 4
 
@@ -978,9 +1030,8 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
             go.Scatterpolar(
                 r=list(azi_alt_sorted.values()),
                 theta=list(azi_alt_sorted.keys()),
-                mode="lines",
-                line_color=var_color,
-                line_width=1,
+                mode="markers",
+                marker=dict(color=var_color, size=2.5),
                 customdata=solpos.altitude,
                 hovertemplate="<br>sun altitude: %{customdata:.2f}"
                 + "\u00B0deg"
@@ -1022,9 +1073,8 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
             go.Scatterpolar(
                 r=list(azi_alt_sorted.values()),
                 theta=list(azi_alt_sorted.keys()),
-                mode="lines",
-                line_color=var_color,
-                line_width=1,
+                mode="markers",
+                marker=dict(color=var_color, size=2.5),
                 customdata=solpos.altitude,
                 hovertemplate="<br>sun altitude: %{customdata:.2f}"
                 + "\u00B0deg"
